betty.test_utils.ancestry.place_type module - Betty documentation

Hide navigation sidebar
Hide table of contents sidebar
Skip to content
Back to top
View this page
Toggle table of contents sidebar

# betty.test_utils.ancestry.place_type module

Test utilities for `betty.ancestry.place_type`.

class betty.test_utils.ancestry.place_type.DummyPlaceType

  Bases: `DummyPlugin`, `PlaceType`

  A dummy place type implementation.

class betty.test_utils.ancestry.place_type.PlaceTypeTestBase

  Bases: `PluginTestBase`[`PlaceType`]

  A base class for testing `betty.ancestry.place_type.PlaceType` implementations.